@@ -355,7 +355,7 @@ impl Kubectl {
 
         let client = self.get_client().await?;
         let statehub_kubectl = statehub_cluster_operator::cluster::Kubectl::new(client);
-        let namespace = statehub_kubectl.create_namespace(&cluster).await?;
+        let namespace = statehub_kubectl.ensure_namespace_exists(&cluster).await?;
         log::debug!("Created namespace: {:#?}", namespace);
         Ok(())
     }
