@@ -393,6 +393,25 @@ enum Command {
         volumes: Vec<v0::VolumeName>,
     },
 
+    #[structopt(
+        about = "Uninstall statehub objects from the cluster",
+        aliases = &["uninstall-sh", "us"],
+        display_order(50)
+    )]
+    UninstallStatehub {
+        #[structopt(help = "Skip confirmation", long, short)]
+        force: bool,
+        #[structopt(help = "Cluster name")]
+        name: v0::ClusterName,
+        #[structopt(
+            help = "Kubeconfig context to use for uninstalling statehub",
+            long,
+            short,
+            visible_alias = "ctx"
+        )]
+        context: Option<String>,
+    },
+
     #[structopt(
         about = "Save cluster token",
         alias = "sct",
@@ -695,6 +714,17 @@ impl Cli {
             } => statehub.set_volume_primary(state, volume, primary).await,
             Command::ListVolumes { state } => statehub.list_volumes(state).await,
             Command::ShowVolumes { state, volumes } => statehub.show_volumes(state, volumes).await,
+            Command::UninstallStatehub {
+                force,
+                name,
+                context,
+            } => {
+                let names = vec![name];
+                let contexts = context.into_iter().collect();
+                let kubectls = k8s::Kubectl::with_names_and_contexts(names, contexts)?;
+
+                statehub.uninstall_statehub(kubectls, force).await
+            }
             Command::SaveClusterToken { namespace, token } => {
                 statehub.save_cluster_token(namespace, token).await
             }
@@ -1132,6 +1162,21 @@ impl StateHub {
         output.into_text(self.json)
     }
 
+    async fn uninstall_statehub(
+        &self,
+        kubectls: Vec<k8s::Kubectl>,
+        force: bool,
+    ) -> anyhow::Result<()> {
+        if force || self.confirm("Are you sure?") {
+            log::info!("Make sure all the pods using statehub are terminated");
+            log::info!("Uninstall helm");
+            for kubectl in kubectls {
+                kubectl.cleanup_statehub_cluster().await?;
+            }
+        }
+        Ok(())
+    }
+
     async fn save_cluster_token(&self, namespace: String, token: String) -> anyhow::Result<()> {
         let secret = k8s::store_cluster_token(&namespace, &token).await?;
         if let Some(token) = k8s::extract_cluster_token(&secret) {
